import numpy as np
import math as math


def percentile(data, percentage):
    """
    Will return the value corresponding to the percentile from the data.

    Difference from numpy.percentile: this function will perform a (n + 1) instead of (n) only
    """
    if type(data) == np.ndarray:
        all_data = data.copy()
        data = data.copy()
    else:
        all_data = data.values.copy()
        data = data.values.copy()
    all_data.sort()
    n = all_data.size
    l = (n + 1) * percentage / 100 - 1

    f_l = math.floor(l)
    c_l = math.ceil(l)

    percentile_val = all_data[f_l] + \
        (all_data[c_l] - all_data[f_l]) * (l - f_l)

    return percentile_val


def percentrank(data, value):
    """
    Will return the corresponding percentile rank given the value.
    """
    if type(data) == np.ndarray:
        all_data = data.copy()
        data = data.copy()
    else:
        all_data = data.values.copy()
        data = data.values.copy()
    all_data.sort()
    l = np.searchsorted(all_data, value, side='left') + 1
    n = all_data.size
    percentage = l * 100 / (n + 1)
    return percentage



#!/usr/bin/env python
import setuptools
import os
from setuptools import setup


def get_version(path):
    with open(path, "r") as f:
        _, version = f.read().strip().split("=")
        version = version.strip().strip('"')
    return version


installations = ['numpy', 'pandas', 'matplotlib', 'adjustText',
                 'scipy', 'ete3', 'seaborn', 'stemgraphic', 'statsmodels', 'plotly']

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="mgt2001",
    version=get_version(os.path.join(
        ".",  # os.path.dirname(os.path.realpath(__file__)),
        "mgt2001",
        "_version.py",
    )),
    author="Brian L. Chen",
    author_email="brian.lxchen@gmail.com",
    description="A small package for MGT 2001 use only",
    long_description_content_type="text/markdown",
    url="https://github.com/icheft/MGT2001_package",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=installations,
    include_package_data=True,
)



from ete3 import Tree, faces, AttrFace, TreeStyle


def ts_layout(node, fgcolor='#FF4ba6', fsize=12):
    '''
    Please set up as the following code shows:

    ```py
    ts = TreeStyle()
    ts.mode = 'r' # 'c'
    ts.min_leaf_separation = 40
    # ts.branch_vertical_margin = 20
    # Do not add leaf names automatically
    ts.show_leaf_name = False
    ts.show_scale = False
    ts.optimal_scale_level = 'mid'
    ts.margin_top = 5
    ts.margin_left = 5
    ts.margin_right = 5
    # Use my custom layout
    ts.layout_fn = ts_layout
    ```
    '''
    node.img_style["size"] = 2
    node.img_style["shape"] = "circle"
    node.img_style["fgcolor"] = fgcolor
    if node.is_leaf():
        # If terminal node, draws its name
        name_face = AttrFace("name", fsize=fsize)  # fgcolor="royalblue"
        name_face.margin_left = 3
        faces.add_face_to_node(name_face, node, column=0,
                               position="branch-right")
    elif not node.is_root():
        # If internal node, draws label with smaller font size
        name_face = AttrFace("name", fsize=fsize)
        name_face.margin_left = 2
        name_face.margin_bottom = 2
        # Adds the name face to the image at the preferred position
        faces.add_face_to_node(name_face, node, column=0,
                               position="branch-top")
        # Possible values are “branch-right”, “branch-top”, “branch-bottom”, “float”, “float-behind” and “aligned”.
